# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PatchedfileFileDistribution(BaseModel):
    """
    Serializer for File Distributions.
    """ # noqa: E501
    base_path: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The base (relative) path component of the published url. Avoid paths that                     overlap with other distribution base paths (e.g. \"foo\" and \"foo/bar\")")
    content_guard: Optional[StrictStr] = Field(default=None, description="An optional content-guard.")
    hidden: Optional[StrictBool] = Field(default=False, description="Whether this distribution should be shown in the content app.")
    pulp_labels: Optional[Dict[str, Optional[StrictStr]]] = None
    name: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A unique name. Ex, `rawhide` and `stable`.")
    repository: Optional[StrictStr] = Field(default=None, description="The latest RepositoryVersion for this Repository will be served.")
    publication: Optional[StrictStr] = Field(default=None, description="Publication to be served")
    checkpoint: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["base_path", "content_guard", "hidden", "pulp_labels", "name", "repository", "publication", "checkpoint"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PatchedfileFileDistribution from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if content_guard (nullable) is None
        # and model_fields_set contains the field
        if self.content_guard is None and "content_guard" in self.model_fields_set:
            _dict['content_guard'] = None

        # set to None if repository (nullable) is None
        # and model_fields_set contains the field
        if self.repository is None and "repository" in self.model_fields_set:
            _dict['repository'] = None

        # set to None if publication (nullable) is None
        # and model_fields_set contains the field
        if self.publication is None and "publication" in self.model_fields_set:
            _dict['publication'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PatchedfileFileDistribution from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "base_path": obj.get("base_path"),
            "content_guard": obj.get("content_guard"),
            "hidden": obj.get("hidden") if obj.get("hidden") is not None else False,
            "pulp_labels": obj.get("pulp_labels"),
            "name": obj.get("name"),
            "repository": obj.get("repository"),
            "publication": obj.get("publication"),
            "checkpoint": obj.get("checkpoint")
        })
        return _obj





# coding: utf-8

# flake8: noqa

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "20260324.1"

# import apis into sdk package
from pulpcore.client.pulp_file.api.acs_file_api import AcsFileApi
from pulpcore.client.pulp_file.api.content_files_api import ContentFilesApi
from pulpcore.client.pulp_file.api.distributions_file_api import DistributionsFileApi
from pulpcore.client.pulp_file.api.publications_file_api import PublicationsFileApi
from pulpcore.client.pulp_file.api.remotes_file_api import RemotesFileApi
from pulpcore.client.pulp_file.api.repositories_file_api import RepositoriesFileApi
from pulpcore.client.pulp_file.api.repositories_file_versions_api import RepositoriesFileVersionsApi

# import ApiClient
from pulpcore.client.pulp_file.api_response import ApiResponse
from pulpcore.client.pulp_file.api_client import ApiClient
from pulpcore.client.pulp_file.configuration import Configuration
from pulpcore.client.pulp_file.exceptions import OpenApiException
from pulpcore.client.pulp_file.exceptions import ApiTypeError
from pulpcore.client.pulp_file.exceptions import ApiValueError
from pulpcore.client.pulp_file.exceptions import ApiKeyError
from pulpcore.client.pulp_file.exceptions import ApiAttributeError
from pulpcore.client.pulp_file.exceptions import ApiException

# import models into sdk package
from pulpcore.client.pulp_file.models.async_operation_response import AsyncOperationResponse
from pulpcore.client.pulp_file.models.content_summary_response import ContentSummaryResponse
from pulpcore.client.pulp_file.models.file_content_upload_response import FileContentUploadResponse
from pulpcore.client.pulp_file.models.file_file_alternate_content_source import FileFileAlternateContentSource
from pulpcore.client.pulp_file.models.file_file_alternate_content_source_response import FileFileAlternateContentSourceResponse
from pulpcore.client.pulp_file.models.file_file_content_response import FileFileContentResponse
from pulpcore.client.pulp_file.models.file_file_distribution import FileFileDistribution
from pulpcore.client.pulp_file.models.file_file_distribution_response import FileFileDistributionResponse
from pulpcore.client.pulp_file.models.file_file_publication import FileFilePublication
from pulpcore.client.pulp_file.models.file_file_publication_response import FileFilePublicationResponse
from pulpcore.client.pulp_file.models.file_file_remote import FileFileRemote
from pulpcore.client.pulp_file.models.file_file_remote_response import FileFileRemoteResponse
from pulpcore.client.pulp_file.models.file_file_remote_response_hidden_fields_inner import FileFileRemoteResponseHiddenFieldsInner
from pulpcore.client.pulp_file.models.file_file_repository import FileFileRepository
from pulpcore.client.pulp_file.models.file_file_repository_response import FileFileRepositoryResponse
from pulpcore.client.pulp_file.models.my_permissions_response import MyPermissionsResponse
from pulpcore.client.pulp_file.models.nested_role import NestedRole
from pulpcore.client.pulp_file.models.nested_role_response import NestedRoleResponse
from pulpcore.client.pulp_file.models.object_roles_response import ObjectRolesResponse
from pulpcore.client.pulp_file.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_alternate_content_source_response_list import PaginatedfileFileAlternateContentSourceResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_content_response_list import PaginatedfileFileContentResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_distribution_response_list import PaginatedfileFileDistributionResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_publication_response_list import PaginatedfileFilePublicationResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_remote_response_list import PaginatedfileFileRemoteResponseList
from pulpcore.client.pulp_file.models.paginatedfile_file_repository_response_list import PaginatedfileFileRepositoryResponseList
from pulpcore.client.pulp_file.models.patchedfile_file_alternate_content_source import PatchedfileFileAlternateContentSource
from pulpcore.client.pulp_file.models.patchedfile_file_distribution import PatchedfileFileDistribution
from pulpcore.client.pulp_file.models.patchedfile_file_remote import PatchedfileFileRemote
from pulpcore.client.pulp_file.models.patchedfile_file_repository import PatchedfileFileRepository
from pulpcore.client.pulp_file.models.policy_enum import PolicyEnum
from pulpcore.client.pulp_file.models.remote_network_config import RemoteNetworkConfig
from pulpcore.client.pulp_file.models.remote_network_config_response import RemoteNetworkConfigResponse
from pulpcore.client.pulp_file.models.repair import Repair
from pulpcore.client.pulp_file.models.repository_add_remove_content import RepositoryAddRemoveContent
from pulpcore.client.pulp_file.models.repository_sync_url import RepositorySyncURL
from pulpcore.client.pulp_file.models.repository_version_response import RepositoryVersionResponse
from pulpcore.client.pulp_file.models.set_label import SetLabel
from pulpcore.client.pulp_file.models.set_label_response import SetLabelResponse
from pulpcore.client.pulp_file.models.task_group_operation_response import TaskGroupOperationResponse
from pulpcore.client.pulp_file.models.unset_label import UnsetLabel
from pulpcore.client.pulp_file.models.unset_label_response import UnsetLabelResponse



# flake8: noqa

# import apis into api package
from pulpcore.client.pulp_file.api.acs_file_api import AcsFileApi
from pulpcore.client.pulp_file.api.content_files_api import ContentFilesApi
from pulpcore.client.pulp_file.api.distributions_file_api import DistributionsFileApi
from pulpcore.client.pulp_file.api.publications_file_api import PublicationsFileApi
from pulpcore.client.pulp_file.api.remotes_file_api import RemotesFileApi
from pulpcore.client.pulp_file.api.repositories_file_api import RepositoriesFileApi
from pulpcore.client.pulp_file.api.repositories_file_versions_api import RepositoriesFileVersionsApi




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from pulpcore.client.pulp_file.models.file_file_repository_response import FileFileRepositoryResponse

class TestFileFileRepositoryResponse(unittest.TestCase):
    """FileFileRepositoryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileFileRepositoryResponse:
        """Test FileFileRepositoryResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileFileRepositoryResponse`
        """
        model = FileFileRepositoryResponse()
        if include_optional:
            return FileFileRepositoryResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                versions_href = '',
                pulp_labels = {
                    'key' : ''
                    },
                latest_version_href = '',
                name = '',
                description = '',
                retain_repo_versions = 1,
                remote = '',
                autopublish = True,
                manifest = 'PULP_MANIFEST'
            )
        else:
            return FileFileRepositoryResponse(
                name = '',
        )
        """

    def testFileFileRepositoryResponse(self):
        """Test FileFileRepositoryResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
